betty.fs module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.fs module

Provide file system utilities.

async betty.fs.iterfiles(path: pathlib.Path) → AsyncIterable[pathlib.Path]

  Recursively iterate over any files found in a directory.

  Parameters:

    path (`pathlib.Path`)

  Return type:

    `typing.AsyncIterable`[`pathlib.Path`]